@@ -99,7 +99,7 @@ class ImageModelTraining:
 
             try:
                 model = model.to(self.device)
-                outputs = model(inputs.float())
+                outputs = model(inputs)
             except Exception as e:
                 print(f"Error while running model: {e}")
                 print("Input size:", inputs.size())
@@ -122,7 +122,7 @@ class ImageModelTraining:
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
-                outputs = model(images.float())
+                outputs = model(images)
                 _, predicted = torch.max(outputs.data, 1)
                 total += labels.size(0)
                 correct += (predicted == labels).sum().item()
@@ -137,7 +137,7 @@ class ImageModelTraining:
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
-                outputs = model(images.float())
+                outputs = model(images)
                 for i in range(outputs.size(0)):  # iterate over batch size
                     output = outputs[i]
                     _, predicted = torch.max(output, 0)
